==> ejc-settlementmanage-impl-3.0.0-20220420.035439-5-sources.jar: com/ejianc/business/settlementmanage/bean/DesignSettlementUnitDetailEntity.java <==
package com.ejianc.business.settlementmanage.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 设计类结算单子表-设计单位
 * 
 * @author generator
 * 
 */
 @TableName("ejc_settlementmanage_design_settlement_unit_detail")
public class DesignSettlementUnitDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表关联键
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同id
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="units")
    private java.lang.String units; // 设计单位
    @TableField(value="units_address")
    private java.lang.String unitsAddress; // 设计单位地址
    @TableField(value="enterprise_nature")
    private java.lang.String enterpriseNature; // 企业性质
    @TableField(value="legal_representative")
    private java.lang.String legalRepresentative; // 法人代表
    @TableField(value="phone")
    private java.lang.String phone; // 联系电话
    @TableField(value="id_card")
    private java.lang.String idCard; // 身份证号码
    @TableField(value="design_content")
    private java.lang.String designContent; // 设计内容
    
    
    

    /**
     * 主表关联键
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表关联键
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 设计单位
     */
    public java.lang.String getUnits() {
        return units;
    }

    /**
     * 设计单位
     */
    public void setUnits(java.lang.String units) {
        this.units = units;
    }
    /**
     * 设计单位地址
     */
    public java.lang.String getUnitsAddress() {
        return unitsAddress;
    }

    /**
     * 设计单位地址
     */
    public void setUnitsAddress(java.lang.String unitsAddress) {
        this.unitsAddress = unitsAddress;
    }
    /**
     * 企业性质
     */
    public java.lang.String getEnterpriseNature() {
        return enterpriseNature;
    }

    /**
     * 企业性质
     */
    public void setEnterpriseNature(java.lang.String enterpriseNature) {
        this.enterpriseNature = enterpriseNature;
    }
    /**
     * 法人代表
     */
    public java.lang.String getLegalRepresentative() {
        return legalRepresentative;
    }

    /**
     * 法人代表
     */
    public void setLegalRepresentative(java.lang.String legalRepresentative) {
        this.legalRepresentative = legalRepresentative;
    }
    /**
     * 联系电话
     */
    public java.lang.String getPhone() {
        return phone;
    }

    /**
     * 联系电话
     */
    public void setPhone(java.lang.String phone) {
        this.phone = phone;
    }
    /**
     * 身份证号码
     */
    public java.lang.String getIdCard() {
        return idCard;
    }

    /**
     * 身份证号码
     */
    public void setIdCard(java.lang.String idCard) {
        this.idCard = idCard;
    }
    /**
     * 设计内容
     */
    public java.lang.String getDesignContent() {
        return designContent;
    }

    /**
     * 设计内容
     */
    public void setDesignContent(java.lang.String designContent) {
        this.designContent = designContent;
    }
    
}

==> ejc-settlementmanage-impl-3.0.0-20240628.063848-285-sources.jar: com/ejianc/business/settlementmanage/bean/DesignSettlementUnitDetailEntity.java <==
package com.ejianc.business.settlementmanage.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 设计类结算单子表-设计单位
 *
 * @author generator
 *
 */
@TableName("ejc_settlementmanage_design_settlement_unit_detail")
public class DesignSettlementUnitDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="mid")
    private java.lang.Long mid; // 主表关联键
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同id
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="units")
    private java.lang.String units; // 设计单位
    @TableField(value="units_address")
    private java.lang.String unitsAddress; // 设计单位地址
    @TableField(value="enterprise_nature")
    private java.lang.String enterpriseNature; // 企业性质
    @TableField(value="legal_representative")
    private java.lang.String legalRepresentative; // 法人代表
    @TableField(value="phone")
    private java.lang.String phone; // 联系电话
    @TableField(value="id_card")
    private java.lang.String idCard; // 身份证号码
    @TableField(value="design_content")
    private java.lang.String designContent; // 设计内容
    @TableField(value="items")
    private java.lang.String items; // 项次
    @TableField(value="sign_content")
    private java.lang.String signContent; // 会签内容及会审人
    @TableField(value="presentation")
    private java.lang.String presentation; // 是否符合合同约定和涉及结算的其它情况说明
    @TableField(value="signature")
    private java.lang.String signature; // 部门相关人员签字确认




    /**
     * 主表关联键
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表关联键
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 设计单位
     */
    public java.lang.String getUnits() {
        return units;
    }

    /**
     * 设计单位
     */
    public void setUnits(java.lang.String units) {
        this.units = units;
    }
    /**
     * 设计单位地址
     */
    public java.lang.String getUnitsAddress() {
        return unitsAddress;
    }

    /**
     * 设计单位地址
     */
    public void setUnitsAddress(java.lang.String unitsAddress) {
        this.unitsAddress = unitsAddress;
    }
    /**
     * 企业性质
     */
    public java.lang.String getEnterpriseNature() {
        return enterpriseNature;
    }

    /**
     * 企业性质
     */
    public void setEnterpriseNature(java.lang.String enterpriseNature) {
        this.enterpriseNature = enterpriseNature;
    }
    /**
     * 法人代表
     */
    public java.lang.String getLegalRepresentative() {
        return legalRepresentative;
    }

    /**
     * 法人代表
     */
    public void setLegalRepresentative(java.lang.String legalRepresentative) {
        this.legalRepresentative = legalRepresentative;
    }
    /**
     * 联系电话
     */
    public java.lang.String getPhone() {
        return phone;
    }

    /**
     * 联系电话
     */
    public void setPhone(java.lang.String phone) {
        this.phone = phone;
    }
    /**
     * 身份证号码
     */
    public java.lang.String getIdCard() {
        return idCard;
    }

    /**
     * 身份证号码
     */
    public void setIdCard(java.lang.String idCard) {
        this.idCard = idCard;
    }
    /**
     * 设计内容
     */
    public java.lang.String getDesignContent() {
        return designContent;
    }

    /**
     * 设计内容
     */
    public void setDesignContent(java.lang.String designContent) {
        this.designContent = designContent;
    }
    /**
     * 项次
     */
    public java.lang.String getItems() {
        return items;
    }

    /**
     * 项次
     */
    public void setItems(java.lang.String items) {
        this.items = items;
    }
    /**
     * 会签内容及会审人
     */
    public java.lang.String getSignContent() {
        return signContent;
    }

    /**
     * 会签内容及会审人
     */
    public void setSignContent(java.lang.String signContent) {
        this.signContent = signContent;
    }
    /**
     * 是否符合合同约定和涉及结算的其它情况说明
     */
    public java.lang.String getPresentation() {
        return presentation;
    }

    /**
     * 是否符合合同约定和涉及结算的其它情况说明
     */
    public void setPresentation(java.lang.String presentation) {
        this.presentation = presentation;
    }
    /**
     * 部门相关人员签字确认
     */
    public java.lang.String getSignature() {
        return signature;
    }

    /**
     * 部门相关人员签字确认
     */
    public void setSignature(java.lang.String signature) {
        this.signature = signature;
    }

}
